# smithed-python
The python package for all things Smithed. Includes weld, cli, and libraries (via [`smithed-libraries`](https://github.com/Smithed-MC/Libraries)).

## Weld
> The fastest pack merger of the west 🚅, build on beet technologies™

- [Docs](https://wiki.smithed.dev/weld/)
